@@ -1,50 +1,49 @@
-#######
-##
-##----- LOSYME
-##----- Config::Any::Log4perl
-##----- Config::Any loader for Log4perl config files 
-##----- Log4perl.pm
-##
-########################################################################################################################
-
+#
+# This file is part of Config-Any-Log4perl
+#
+# This software is copyright (c) 2012 by Loïc TROCHET.
+#
+# This is free software; you can redistribute it and/or modify it under
+# the same terms as the Perl 5 programming language system itself.
+#
 package Config::Any::Log4perl;
+{
+  $Config::Any::Log4perl::VERSION = '0.130020';
+}
+# ABSTRACT: Config::Any loader for Log4perl config files
 
 use strict;
-use warnings FATAL => qw(all);
-
-our $VERSION   =   '0.02';
-our $AUTHORITY = 'LOSYME';
+use warnings;
 
+use Config::Any::Base;
 use parent qw(Config::Any::Base);
 
-###-------------------------------------------------------------------------------------------------------------------##
-### Return an array of valid extensions.
+
 sub extensions
 {
     return qw(log4perl);
 }
 
-###-------------------------------------------------------------------------------------------------------------------##
-### Attempts to load a Log4perl config file.
+
 sub load
 {
     my $class = shift;
     my $file  = shift;
     my $args  = shift || {};
-    
+
     open(FILE, $file) or die "Failed to open file <$file>: $!";
     my @lines  = <FILE>;
-    
+
     return {} unless grep /\S/, @lines;
-    
+
     my $config = {};
-    
+
     while (@lines)
     {
         local $_ = shift @lines;
         s/^\s*#.*//;
         next unless /\S/;
-        
+
         while (/(.+?)\\\s*$/)
         {
             my $prev = $1;
@@ -54,7 +53,7 @@ sub load
             $_ = $prev . $next;
             chomp;
         }
-        
+
         if (my ($key, $val) = /(\S+?)\s*=\s*(.*)/)
         {
             $val =~ s/\s+$//;
@@ -73,24 +72,24 @@ __END__
 
 =head1 NAME
 
-Config::Any::Log4perl - Config::Any loader for Log4perl config files.
+Config::Any::Log4perl - Config::Any loader for Log4perl config files
 
 =head1 VERSION
 
-Version 0.02
+version 0.130020
 
 =head1 SYNOPSIS
 
     use Config::Any;
-    
+
     ...
-    
+
     my $config = Config::Any->load_files({
           files => \@files
         , use_ext => 1
         , driver_args => { Log4perl => { config_name => 'logger' }}
     });
-    
+
     ...
 
 See L<Config::Any>
@@ -168,7 +167,7 @@ If B<config_name> is undefined the return value is:
 If B<config_name> is defined like this:
 
     config_name => 'logger'
-    
+
 the return value is:
 
     {
@@ -187,20 +186,17 @@ the return value is:
 
 L<Log::Log4perl>
 
+=encoding utf8
+
 =head1 AUTHOR
 
-LoE<iuml>c TROCHET E<lt>losyme@gmail.comE<gt>
-
-Repository available at L<https://github.com/losyme/Config-Any-Log4perl>.
+Loïc TROCHET <losyme@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2012 by LoE<iuml>c TROCHET.
+This software is copyright (c) 2012 by Loïc TROCHET.
 
-This library is free software; you can redistribute it and/or modify it under the same terms as Perl itself.
-
-See L<http://dev.perl.org/licenses/> for more information.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
-
-####### END ############################################################################################################
